"""
Defining filepaths used by mpc_orb
"""

# Import standard packages
# -----------------------
import glob

# Directories / Filepaths / ...
# -----------------------
# Relative filepath to json schema against which everything is validated
# - Gets the highest-numbered version in the directory
schema_relative_filepath = "schema_json/mpcorb_schema_latest.json"

